==> aruba-central-migrate-0.0.14.tar.gz: aruba-central-migrate-0.0.14/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / "README.md").read_text(encoding="utf-8")

# Arguments marked as "Required" below must be included for upload to PyPI.
# Fields marked as "Optional" may be commented out.

setup(
    # This is the name of your project. The first time you publish this
    # package, this name will be registered for you. It will determine how
    # users can install this project, e.g.:
    #
    # $ pip install sampleproject

    name="aruba-central-migrate",  # Required
    
    version="0.0.14",  # Required
    # This is a one-line description or tagline of what your project does. This
    
    description="A sample Python project",  # Optional
    # This is an optional longer description of your project that represents
    
    long_description=long_description,  # Optional
   
    long_description_content_type="text/markdown",
    
    url="https://github.com/pypa/sampleproject",  # Optional
    
    author="PK",  # Optional
    
    author_email="prathibha-k@hpe.com",  # Optional
    
    classifiers=[  # Optional
        # Pick your license as you wish
        "License :: OSI Approved :: MIT License",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate you support Python 3. These classifiers are *not*
        # checked by 'pip install'. See instead 'python_requires' below.
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
    ],
   
    package_dir={"": "src"},  # Optional
    
    packages=find_packages(where="src"),  # Required
    
    python_requires=">=3.7, <4",
    
    install_requires=[
        # "aiohttp==3.7.4.post0",
        # "altgraph==0.17",
        # "async-timeout==3.0.1",
        "asyncio==3.4.3"
        # "attrs==21.2.0",
        # "certifi==2020.12.5",
        # "chardet==4.0.0",
        # "cx-Freeze==6.6",
        # "et-xmlfile==1.1.0",
        # "idna==2.10",
        # "importlib-metadata==4.4.0",
        # "Jinja2==3.0.1",
        # "macholib==1.14",
        # "MarkupSafe==2.0.1",
        # "multidict==5.1.0",
        # "numpy==1.20.3",
        # "openpyxl==3.0.7",
        # "pandas==1.2.4",
        # "peewee==3.14.4",
        # "pyinstaller==4.3",
        # "pyinstaller-hooks-contrib==2021.1",
        # "python-dateutil==2.8.1",
        # "pytz==2021.1",
        # "requests==2.25.1",
        # "six==1.16.0",
        # "typing-extensions==3.10.0.0",
        # "urllib3==1.26.4",
        # "xlrd==2.0.1",
        # "XlsxWriter==1.4.3",
        # "yarl==1.6.3",
        # "zipp==3.4.1",
    ] # Optional

    # extras_require={  # Optional
    #     "dev": ["pandas>=1.1.5"],
    #     "test": ["coverage"],
    # },
    # List additional groups of dependencies here (e.g. development
    # dependencies). Users will be able to install these using the "extras"
    # syntax, for example:
    #
    #   $ pip install sampleproject[dev]
    #
    # Similar to `install_requires` above, these must be valid existing
    # projects.

    
)

==> aruba-central-migrate-0.0.16.tar.gz: aruba-central-migrate-0.0.16/setup.py <==
"""A setuptools based setup module.

See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / "README.md").read_text(encoding="utf-8")

# Arguments marked as "Required" below must be included for upload to PyPI.
# Fields marked as "Optional" may be commented out.

setup(
    # This is the name of your project. The first time you publish this
    # package, this name will be registered for you. It will determine how
    # users can install this project, e.g.:
    #
    # $ pip install sampleproject

    name="aruba-central-migrate",  # Required
    
    version="0.0.16",  # Required
    # This is a one-line description or tagline of what your project does. This
    
    description="A sample Python project",  # Optional
    # This is an optional longer description of your project that represents
    
    long_description=long_description,  # Optional
   
    long_description_content_type="text/markdown",
    
    url="https://github.com/pypa/sampleproject",  # Optional
    
    author="PK",  # Optional
    
    author_email="prathibha-k@hpe.com",  # Optional
    
    classifiers=[  # Optional
        # Pick your license as you wish
        "License :: OSI Approved :: MIT License",
        # Specify the Python versions you support here. In particular, ensure
        # that you indicate you support Python 3. These classifiers are *not*
        # checked by 'pip install'. See instead 'python_requires' below.
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
    ],
   
    package_dir={"": "central"},  # Optional
    
    packages=find_packages(where="device_inventory"),  # Required
    
    python_requires=">=3.7, <4",
    
    install_requires=[
        # "aiohttp==3.7.4.post0",
        # "altgraph==0.17",
        # "async-timeout==3.0.1",
        "asyncio==3.4.3"
        # "attrs==21.2.0",
        # "certifi==2020.12.5",
        # "chardet==4.0.0",
        # "cx-Freeze==6.6",
        # "et-xmlfile==1.1.0",
        # "idna==2.10",
        # "importlib-metadata==4.4.0",
        # "Jinja2==3.0.1",
        # "macholib==1.14",
        # "MarkupSafe==2.0.1",
        # "multidict==5.1.0",
        # "numpy==1.20.3",
        # "openpyxl==3.0.7",
        # "pandas==1.2.4",
        # "peewee==3.14.4",
        # "pyinstaller==4.3",
        # "pyinstaller-hooks-contrib==2021.1",
        # "python-dateutil==2.8.1",
        # "pytz==2021.1",
        # "requests==2.25.1",
        # "six==1.16.0",
        # "typing-extensions==3.10.0.0",
        # "urllib3==1.26.4",
        # "xlrd==2.0.1",
        # "XlsxWriter==1.4.3",
        # "yarl==1.6.3",
        # "zipp==3.4.1",
    ] # Optional

    # extras_require={  # Optional
    #     "dev": ["pandas>=1.1.5"],
    #     "test": ["coverage"],
    # },
    # List additional groups of dependencies here (e.g. development
    # dependencies). Users will be able to install these using the "extras"
    # syntax, for example:
    #
    #   $ pip install sampleproject[dev]
    #
    # Similar to `install_requires` above, these must be valid existing
    # projects.

    
)
